Index: src/compiler/linkage.h |
diff --git a/src/compiler/linkage.h b/src/compiler/linkage.h |
index 01911e6ee246b33c08983001a5fc2d51c1d5b319..a0434f8afff6c2651bf8ac60e7f588c07bb77c28 100644 |
--- a/src/compiler/linkage.h |
+++ b/src/compiler/linkage.h |
@@ -160,10 +160,11 @@ class CallDescriptor final : public ZoneObject { |
kCanUseRoots = 1u << 6, |
// (arm64 only) native stack should be used for arguments. |
kUseNativeStack = 1u << 7, |
// (arm64 only) call instruction has to restore JSSP. |
kRestoreJSSP = 1u << 8, |
+ kRestoreCSP = 1u << 9, |
// Causes the code generator to initialize the root register. |
- kInitializeRootRegister = 1u << 9, |
+ kInitializeRootRegister = 1u << 10, |
kPatchableCallSiteWithNop = kPatchableCallSite | kNeedsNopAfterCall |
}; |
typedef base::Flags<Flag> Flags; |
@@ -160,10 +160,11 @@ class CallDescriptor final : public ZoneObject { |
// (arm64 only) native stack should be used for arguments. |
kUseNativeStack = 1u << 7, |
- // (arm64 only) call instruction has to restore JSSP. |
+ // (arm64 only) call instruction has to restore JSSP or CSP. |
kRestoreJSSP = 1u << 8, |